@@ -17,8 +17,7 @@ from src.cryptonets_python_sdk.settings.loggingLevel import LoggingLevel
 from src.cryptonets_python_sdk.settings.cacheType import CacheType
 from src.cryptonets_python_sdk.helper.utils import FaceValidationCode
 
-os.environ["PI_SERVER_URL"] = "https://api.prodv3.cryptonets.ai/node"
-os.environ["PI_API_KEY"] = "next540d2759da134690"
+
 def image_path_to_array(image_path: str) -> np.ndarray:
     image = Image.open(image_path).convert("RGB")
     return np.array(image)
